summaryrefslogtreecommitdiffstats
path: root/keyboards/xd75/keymaps
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/xd75/keymaps')
-rw-r--r--keyboards/xd75/keymaps/adi/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/adi/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/atomic_style/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/atomic_style/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/bbaserdem/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/boy_314/keymap.c6
-rw-r--r--keyboards/xd75/keymaps/bramver/keymap.c2
-rw-r--r--keyboards/xd75/keymaps/c4software_bepo/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/cbbrowne/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/default/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/default/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/dyn_macro_tap_dance/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/dyn_macro_tap_dance/rules.mk5
-rw-r--r--keyboards/xd75/keymaps/emilyh/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/emilyh/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/fabian/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/french/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/french/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/germanized/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/kim-kim-xd73/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/kim-kim-xd73/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/kim-kim/keymap.c4
-rw-r--r--keyboards/xd75/keymaps/kim-kim/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/kloki/keymap.c3
-rw-r--r--keyboards/xd75/keymaps/kloki/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/markus/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/mtdjr/rules.mk5
-rw-r--r--keyboards/xd75/keymaps/skewwhiffy/keymap.c8
-rw-r--r--keyboards/xd75/keymaps/skewwhiffy/rules.mk3
-rw-r--r--keyboards/xd75/keymaps/tdl-jturner/rules.mk5
30 files changed, 7 insertions, 106 deletions
diff --git a/keyboards/xd75/keymaps/adi/keymap.c b/keyboards/xd75/keymaps/adi/keymap.c
index d96a21507..24b450c8d 100644
--- a/keyboards/xd75/keymaps/adi/keymap.c
+++ b/keyboards/xd75/keymaps/adi/keymap.c
@@ -106,10 +106,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
},
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/adi/rules.mk b/keyboards/xd75/keymaps/adi/rules.mk
index d4e08cfb2..52a8f38d4 100644
--- a/keyboards/xd75/keymaps/adi/rules.mk
+++ b/keyboards/xd75/keymaps/adi/rules.mk
@@ -13,6 +13,3 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/atomic_style/keymap.c b/keyboards/xd75/keymaps/atomic_style/keymap.c
index 986732299..c40d89bc7 100644
--- a/keyboards/xd75/keymaps/atomic_style/keymap.c
+++ b/keyboards/xd75/keymaps/atomic_style/keymap.c
@@ -163,10 +163,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
},
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/atomic_style/rules.mk b/keyboards/xd75/keymaps/atomic_style/rules.mk
index d4e08cfb2..52a8f38d4 100644
--- a/keyboards/xd75/keymaps/atomic_style/rules.mk
+++ b/keyboards/xd75/keymaps/atomic_style/rules.mk
@@ -13,6 +13,3 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/bbaserdem/rules.mk b/keyboards/xd75/keymaps/bbaserdem/rules.mk
index 4839c644f..3e501cd00 100644
--- a/keyboards/xd75/keymaps/bbaserdem/rules.mk
+++ b/keyboards/xd75/keymaps/bbaserdem/rules.mk
@@ -5,6 +5,3 @@ RGBLIGHT_ENABLE = no # LED strips
TAP_DANCE_ENABLE = no # Use multi-tap features
AUDIO_ENABLE = no # Audio stuff
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/boy_314/keymap.c b/keyboards/xd75/keymaps/boy_314/keymap.c
index d807d1d86..1de733f0f 100644
--- a/keyboards/xd75/keymaps/boy_314/keymap.c
+++ b/keyboards/xd75/keymaps/boy_314/keymap.c
@@ -125,12 +125,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
}
};
-
-
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/bramver/keymap.c b/keyboards/xd75/keymaps/bramver/keymap.c
index 831278d00..142d8efd2 100644
--- a/keyboards/xd75/keymaps/bramver/keymap.c
+++ b/keyboards/xd75/keymaps/bramver/keymap.c
@@ -96,8 +96,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
};
-const uint16_t PROGMEM fn_actions[] = {};
-
void matrix_init_user(void) {
_delay_ms(20); // Gets rid of tick
set_unicode_input_mode(UC_LNX);
diff --git a/keyboards/xd75/keymaps/c4software_bepo/keymap.c b/keyboards/xd75/keymaps/c4software_bepo/keymap.c
index e0a71d7c4..2c70f2876 100644
--- a/keyboards/xd75/keymaps/c4software_bepo/keymap.c
+++ b/keyboards/xd75/keymaps/c4software_bepo/keymap.c
@@ -67,10 +67,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
}
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/cbbrowne/keymap.c b/keyboards/xd75/keymaps/cbbrowne/keymap.c
index ec98b6d5a..322fffdad 100644
--- a/keyboards/xd75/keymaps/cbbrowne/keymap.c
+++ b/keyboards/xd75/keymaps/cbbrowne/keymap.c
@@ -197,10 +197,6 @@ Missing still...
},
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
/* This bit of logic seeds a wee linear congruential random number generator */
/* lots of prime numbers everywhere... */
static uint16_t random_value = 157;
diff --git a/keyboards/xd75/keymaps/default/keymap.c b/keyboards/xd75/keymaps/default/keymap.c
index 028fc270d..03f605385 100644
--- a/keyboards/xd75/keymaps/default/keymap.c
+++ b/keyboards/xd75/keymaps/default/keymap.c
@@ -66,10 +66,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
}
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/default/rules.mk b/keyboards/xd75/keymaps/default/rules.mk
index d4e08cfb2..52a8f38d4 100644
--- a/keyboards/xd75/keymaps/default/rules.mk
+++ b/keyboards/xd75/keymaps/default/rules.mk
@@ -13,6 +13,3 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/dyn_macro_tap_dance/keymap.c b/keyboards/xd75/keymaps/dyn_macro_tap_dance/keymap.c
index 52cae7f71..594e5c41c 100644
--- a/keyboards/xd75/keymaps/dyn_macro_tap_dance/keymap.c
+++ b/keyboards/xd75/keymaps/dyn_macro_tap_dance/keymap.c
@@ -114,10 +114,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
}
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/dyn_macro_tap_dance/rules.mk b/keyboards/xd75/keymaps/dyn_macro_tap_dance/rules.mk
index 64484d3ee..7708eba6a 100644
--- a/keyboards/xd75/keymaps/dyn_macro_tap_dance/rules.mk
+++ b/keyboards/xd75/keymaps/dyn_macro_tap_dance/rules.mk
@@ -13,8 +13,5 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
-
TAP_DANCE_ENABLE = yes
+
diff --git a/keyboards/xd75/keymaps/emilyh/keymap.c b/keyboards/xd75/keymaps/emilyh/keymap.c
index 034bb55ac..04c239636 100644
--- a/keyboards/xd75/keymaps/emilyh/keymap.c
+++ b/keyboards/xd75/keymaps/emilyh/keymap.c
@@ -164,10 +164,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
},
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/emilyh/rules.mk b/keyboards/xd75/keymaps/emilyh/rules.mk
index d4e08cfb2..52a8f38d4 100644
--- a/keyboards/xd75/keymaps/emilyh/rules.mk
+++ b/keyboards/xd75/keymaps/emilyh/rules.mk
@@ -13,6 +13,3 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/fabian/rules.mk b/keyboards/xd75/keymaps/fabian/rules.mk
index f1ae8d44a..8831f2d62 100644
--- a/keyboards/xd75/keymaps/fabian/rules.mk
+++ b/keyboards/xd75/keymaps/fabian/rules.mk
@@ -32,6 +32,3 @@ BLUETOOTH_ENABLE = no # Enable Bluetooth with the Adafruit EZ-Key HID
RGBLIGHT_ENABLE = yes # Enable WS2812 RGB underlight.
SLEEP_LED_ENABLE = no # Breathing sleep LED during USB suspend
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/french/keymap.c b/keyboards/xd75/keymaps/french/keymap.c
index a5d14674a..1ffec2202 100644
--- a/keyboards/xd75/keymaps/french/keymap.c
+++ b/keyboards/xd75/keymaps/french/keymap.c
@@ -54,7 +54,3 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
{ RESET, FR_EMPT, FR_EMPT, FR_TRANS, FR_EMPT, FR_EMPT, FR_EMPT, FR_EMPT, FR_EMPT, FR_EMPT, FR_0, FR_DOT, FR_ENTK, FR_EMPT, BL_STEP },
},
};
-
-const uint16_t PROGMEM fn_actions[] = {
-};
-
diff --git a/keyboards/xd75/keymaps/french/rules.mk b/keyboards/xd75/keymaps/french/rules.mk
index dfd79792f..324d9ebd0 100644
--- a/keyboards/xd75/keymaps/french/rules.mk
+++ b/keyboards/xd75/keymaps/french/rules.mk
@@ -15,6 +15,3 @@
RGBLIGHT_ENABLE = no
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/germanized/rules.mk b/keyboards/xd75/keymaps/germanized/rules.mk
index f57fb8c54..ab81a5360 100644
--- a/keyboards/xd75/keymaps/germanized/rules.mk
+++ b/keyboards/xd75/keymaps/germanized/rules.mk
@@ -33,6 +33,3 @@ RGBLIGHT_ENABLE = yes # Enable WS2812 RGB underlight.
SLEEP_LED_ENABLE = no # Breathing sleep LED during USB suspend
TAP_DANCE_ENABLE = yes # Enable Tap Dancing
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/kim-kim-xd73/keymap.c b/keyboards/xd75/keymaps/kim-kim-xd73/keymap.c
index 19f13ed32..8820b4ef5 100644
--- a/keyboards/xd75/keymaps/kim-kim-xd73/keymap.c
+++ b/keyboards/xd75/keymaps/kim-kim-xd73/keymap.c
@@ -118,10 +118,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/kim-kim-xd73/rules.mk b/keyboards/xd75/keymaps/kim-kim-xd73/rules.mk
index 7e4ed0837..4c894d797 100644
--- a/keyboards/xd75/keymaps/kim-kim-xd73/rules.mk
+++ b/keyboards/xd75/keymaps/kim-kim-xd73/rules.mk
@@ -20,6 +20,3 @@
#
BACKLIGHT_ENABLE = yes # Enable keyboard backlight functionality
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/kim-kim/keymap.c b/keyboards/xd75/keymaps/kim-kim/keymap.c
index 0ec506e17..c67ce2287 100644
--- a/keyboards/xd75/keymaps/kim-kim/keymap.c
+++ b/keyboards/xd75/keymaps/kim-kim/keymap.c
@@ -118,10 +118,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
-
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
// MACRODOWN only works in this function
diff --git a/keyboards/xd75/keymaps/kim-kim/rules.mk b/keyboards/xd75/keymaps/kim-kim/rules.mk
index 7e4ed0837..4c894d797 100644
--- a/keyboards/xd75/keymaps/kim-kim/rules.mk
+++ b/keyboards/xd75/keymaps/kim-kim/rules.mk
@@ -20,6 +20,3 @@
#
BACKLIGHT_ENABLE = yes # Enable keyboard backlight functionality
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/kloki/keymap.c b/keyboards/xd75/keymaps/kloki/keymap.c
index 62023cf70..340d9a8dc 100644
--- a/keyboards/xd75/keymaps/kloki/keymap.c
+++ b/keyboards/xd75/keymaps/kloki/keymap.c
@@ -64,9 +64,6 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
{ _______, _______, _______, _______, _______,_______,_______, _______, _______, _______,_______,_______, _______, _______, _______ },
}
};
-const uint16_t PROGMEM fn_actions[] = {
-
-};
const macro_t *action_get_macro(keyrecord_t *record, uint8_t id, uint8_t opt)
{
diff --git a/keyboards/xd75/keymaps/kloki/rules.mk b/keyboards/xd75/keymaps/kloki/rules.mk
index d4e08cfb2..52a8f38d4 100644
--- a/keyboards/xd75/keymaps/kloki/rules.mk
+++ b/keyboards/xd75/keymaps/kloki/rules.mk
@@ -13,6 +13,3 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/markus/rules.mk b/keyboards/xd75/keymaps/markus/rules.mk
index febb446f8..d0ed9a73a 100644
--- a/keyboards/xd75/keymaps/markus/rules.mk
+++ b/keyboards/xd75/keymaps/markus/rules.mk
@@ -21,6 +21,3 @@ API_SYSEX_ENABLE = no
# Do not enable SLEEP_LED_ENABLE. it uses the same timer as BACKLIGHT_ENABLE
SLEEP_LED_ENABLE = no # Breathing sleep LED during USB suspend
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/mtdjr/rules.mk b/keyboards/xd75/keymaps/mtdjr/rules.mk
index 28462ff16..6b7d69d4f 100644
--- a/keyboards/xd75/keymaps/mtdjr/rules.mk
+++ b/keyboards/xd75/keymaps/mtdjr/rules.mk
@@ -13,10 +13,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
-
BACKLIGHT_ENABLE = yes
TAP_DANCE_ENABLE = yes
RGBLIGHT_ENABLE = yes
+
diff --git a/keyboards/xd75/keymaps/skewwhiffy/rules.mk b/keyboards/xd75/keymaps/skewwhiffy/rules.mk
index d4e08cfb2..52a8f38d4 100644
--- a/keyboards/xd75/keymaps/skewwhiffy/rules.mk
+++ b/keyboards/xd75/keymaps/skewwhiffy/rules.mk
@@ -13,6 +13,3 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
diff --git a/keyboards/xd75/keymaps/tdl-jturner/rules.mk b/keyboards/xd75/keymaps/tdl-jturner/rules.mk
index 186b452fc..996d77045 100644
--- a/keyboards/xd75/keymaps/tdl-jturner/rules.mk
+++ b/keyboards/xd75/keymaps/tdl-jturner/rules.mk
@@ -13,11 +13,8 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-ifndef QUANTUM_DIR
- include ../../../../Makefile
-endif
-
TAP_DANCE_ENABLE = yes
MOUSEKEY_ENABLE = yes
BACKLIGHT_ENABLE = yes
RGBLIGHT_ENABLE = yes
+
diff --git a/keyboards/xd75/keymaps/skewwhiffy/keymap.c b/keyboards/xd75/keymaps/skewwhiffy/keymap.c
index 33f386808..ab0213862 100644
--- a/keyboards/xd75/keymaps/skewwhiffy/keymap.c
+++ b/keyboards/xd75/keymaps/skewwhiffy/keymap.c
@@ -76,18 +76,18 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* |--------------------------------------------------------------------------------------------------------------------------------------|
* | A | R | S | T | D | | | | | | H | N | E | I | O |
* |--------------------------------------------------------------------------------------------------------------------------------------|
- * | Z | X | C | V | B | | | | | | K | M | , | . | / |
+ * | Z | X | C | V | B | | | UP | | | K | M | , | . | / |
* | SHIFT | NUMBER | SYMBOL | NAV | | | | | | | | NAV | SYMBOL | FUNC | SHIFT |
* |--------------------------------------------------------------------------------------------------------------------------------------|
* | LSHIFT | LCTRL | LALT | LGUI | SPACE | ENT | | | | DEL | BKSPC | RGUI | RALT | RCTRL | RSHIFT |
* .--------------------------------------------------------------------------------------------------------------------------------------.
*/
[cm] = LAYOUT_ortho_5x15( \
_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, \
UK_Q, UK_W, UK_F, UK_P, UK_G, _______, _______, _______, _______, _______, UK_J, UK_L, UK_U, UK_Y, UK_SCLN, \
UK_A, UK_R, UK_S, UK_T, UK_D, _______, _______, _______, _______, _______, UK_H, UK_N, UK_E, UK_I, UK_O , \
- _Z_SFT, _X_NB, _C_SY, _V_NAL, UK_B, _______, _______, _______, _______, _______, UK_K, _M_NAR, _COM_SY, _DOT_NB, _SLSH , \
- UK_LSFT, UK_LCTL, UK_LALT, UK_LGUI, UK_SPC, UK_ENT, _______, _______, _______, UK_DEL, UK_BSPC, UK_RGUI, UK_RALT, UK_RCTL, UK_RSFT \
+ _Z_SFT, _X_NB, _C_SY, _V_NAL, UK_B, _______, _______, UK_UP, _______, _______, UK_K, _M_NAR, _COM_SY, _DOT_NB, _SLSH , \
+ UK_LSFT, UK_LCTL, UK_LALT, UK_LGUI, UK_SPC, UK_ENT, UK_LEFT, UK_DOWN, UK_RGHT, UK_DEL, UK_BSPC, UK_RGUI, UK_RALT, UK_RCTL, UK_RSFT \
),
/* Dvorak
@@ -76,18 +76,18 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* | SHIFT | NUMBER | SYMBOL | NAV | | | | | | | | NAV | SYMBOL | FUNC | SHIFT |
* |--------------------------------------------------------------------------------------------------------------------------------------|
- * | LSHIFT | LCTRL | LALT | LGUI | SPACE | ENT | | | | DEL | BKSPC | RGUI | RALT | RCTRL | RSHIFT |
+ * | LSHIFT | LCTRL | LALT | LGUI | SPACE | ENT | LEFT | DOWN | RIGHT | DEL | BKSPC | RGUI | RALT | RCTRL | RSHIFT |
* .--------------------------------------------------------------------------------------------------------------------------------------.
*/